@@ -203,9 +203,9 @@ Notes without time appear first, then sorted by time ascending."
          (--filter (or (not vulpea-journal-ui-created-today-exclude-journal)
                        (not (vulpea-journal-note-p it))))
          (--sort (let ((time-a (vulpea-journal-ui--extract-time
-                                (alist-get 'CREATED (vulpea-note-properties it))))
+                                (cdr (assoc "CREATED" (vulpea-note-properties it)))))
                        (time-b (vulpea-journal-ui--extract-time
-                                (alist-get 'CREATED (vulpea-note-properties other)))))
+                                (cdr (assoc "CREATED" (vulpea-note-properties other))))))
                    (cond
                     ;; Both have no time - keep original order
                     ((and (null time-a) (null time-b)) nil)
@@ -400,13 +400,13 @@ ON-SELECT is callback to handle date selection."
       :children
       (lambda ()
         (if (null notes)
-            (vui-text "No notes created today" :face 'shadow)
+            (vui-muted "No notes created today")
           (vui-list
            notes
            (lambda (n)
              (let* ((title (vulpea-note-title n))
                     (tags (vulpea-note-tags n))
-                    (created (alist-get 'CREATED (vulpea-note-properties n)))
+                    (created (cdr (assoc "CREATED" (vulpea-note-properties n))))
                     (time-str (if (and created (string-match "\\([0-9]+:[0-9]+\\)" created))
                                   (match-string 1 created)
                                 "     "))
@@ -416,14 +416,13 @@ ON-SELECT is callback to handle date selection."
                                     (vulpea-visit n)))))
                (vui-hstack
                 :spacing 1
-                (vui-text time-str :face 'shadow)
+                (vui-muted time-str)
                 (vui-button title
                   :face 'link
                   :help-echo nil
                   :on-click visit-note)
                 (when tags
-                  (vui-text (string-join (--map (concat "#" it) tags) " ")
-                    :face 'shadow)))))
+                  (vui-muted (string-join (--map (concat "#" it) tags) " "))))))
            #'vulpea-note-id))))))
 
 ;;; Previous Years Widget
@@ -457,10 +456,9 @@ ON-SELECT is callback to handle date selection."
         :face 'link
         :help-echo nil
         :on-click visit-note)
-      (vui-text (format "(%d year%s ago)"
-                        years-ago
-                        (if (= years-ago 1) "" "s"))
-        :face 'shadow))
+      (vui-muted (format "(%d year%s ago)"
+                         years-ago
+                         (if (= years-ago 1) "" "s"))))
      (when (and expanded preview)
        (vui-text (vulpea-journal-ui--indent-text (concat preview "...") 4)
          :face 'font-lock-comment-face)))))
@@ -486,7 +484,7 @@ ON-SELECT is callback to handle date selection."
       :children
       (lambda ()
         (if (null entries)
-            (vui-text "No entries from previous years" :face 'shadow)
+            (vui-muted "No entries from previous years")
           (vui-list entries
                     (lambda (entry)
                       (vui-component 'vulpea-journal-widget-previous-year-entry
@@ -542,7 +540,7 @@ Works whether called from sidebar or main window."
 
 (defun vulpea-journal-ui-date (date)
   "Navigate to journal for DATE from sidebar."
-  (interactive (list (vulpea-journal--read-date)))
+  (interactive (list (vulpea-journal--read-date "Journal date: ")))
   (vulpea-journal-ui--visit-date date))
 
 ;;; Widget Registration
